Crate opcda_bridge_client

Crate opcda_bridge_client 

Modules

cli
commands
config
output
Output format selection and rendering for client command results.

Functions

run
Parse CLI arguments and run, returning a process exit code.